@@ -1,18 +1,17 @@
 pub mod allocator;
 pub mod chia_dialect;
-mod core_ops;
+pub mod core_ops;
 pub mod cost;
-mod dialect;
-mod err_utils;
-mod gen;
+pub mod dialect;
+pub mod err_utils;
+pub mod f_table;
 pub mod more_ops;
 pub mod node;
 pub mod number;
 pub mod op_utils;
-#[cfg(not(any(test, target_family = "wasm")))]
-pub mod py;
 pub mod reduction;
 pub mod run_program;
+pub mod runtime_dialect;
 pub mod serialize;
 pub mod sha2;
 
@@ -21,6 +20,3 @@ mod tests;
 
 #[cfg(test)]
 mod test_ops;
-
-#[cfg(target_family = "wasm")]
-pub mod wasm;
